==> jc-colgate-domain-0.0.85-sources.jar: com/xforceplus/ultraman/app/jccolgate/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.jccolgate.metadata;

/**
 *
 * @author ultraman
 * @since 2021-09-07
 */

public class PageMeta {
    public interface SellerInvoice {
        static String code() {
            return "sellerInvoice";
        }
        static String name() {
            return "销项发票";
        }
    }
    public interface SalesBill {
        static String code() {
            return "salesBill";
        }
        static String name() {
            return "业务单";
        }
    }
    public interface DiscountRuleConfig {
        static String code() {
            return "discountRuleConfig";
        }
        static String name() {
            return "折扣规则配置";
        }
    }
    public interface ScannedDat {
        static String code() {
            return "scannedDat";
        }
        static String name() {
            return "已扫描的Dat文件";
        }
    }
    public interface SourceData {
        static String code() {
            return "sourceData";
        }
        static String name() {
            return "源数据";
        }
    }
    public interface SalesBillDetail {
        static String code() {
            return "salesBillDetail";
        }
        static String name() {
            return "业务单明细管理";
        }
    }
    public interface SellerInvoiceDetail {
        static String code() {
            return "sellerInvoiceDetail";
        }
        static String name() {
            return "发票明细管理";
        }
    }
    public interface SalesBillDetailCount {
        static String code() {
            return "salesBillDetailCount";
        }
        static String name() {
            return "明细行数量记录";
        }
    }
    public interface TaskLog {
        static String code() {
            return "taskLog";
        }
        static String name() {
            return "定时任务执行日志";
        }
    }
    public interface ExpectionLog {
        static String code() {
            return "expectionLog";
        }
        static String name() {
            return "业务错误日志";
        }
    }
    public interface ProductCodeConfig {
        static String code() {
            return "productCodeConfig";
        }
        static String name() {
            return "主商品配置表";
        }
    }
    public interface ProductNameKeyword {
        static String code() {
            return "productNameKeyword";
        }
        static String name() {
            return "商品名称关键维护";
        }
    }
}

==> jc-colgate-domain-0.0.91-sources.jar: com/xforceplus/ultraman/app/jccolgate/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.jccolgate.metadata;

/**
 *
 * @author ultraman
 * @since 2021-09-28
 */

public class PageMeta {
    public interface SellerInvoice {
        static String code() {
            return "sellerInvoice";
        }
        static String name() {
            return "销项发票管理";
        }
    }
    public interface SalesBill {
        static String code() {
            return "salesBill";
        }
        static String name() {
            return "业务单管理";
        }
    }
    public interface DiscountRuleConfig {
        static String code() {
            return "discountRuleConfig";
        }
        static String name() {
            return "折扣规则配置";
        }
    }
    public interface ScannedDat {
        static String code() {
            return "scannedDat";
        }
        static String name() {
            return "DAT上传履历";
        }
    }
    public interface SourceData {
        static String code() {
            return "sourceData";
        }
        static String name() {
            return "源数据管理";
        }
    }
    public interface SalesBillDetail {
        static String code() {
            return "salesBillDetail";
        }
        static String name() {
            return "业务单明细管理";
        }
    }
    public interface SellerInvoiceDetail {
        static String code() {
            return "sellerInvoiceDetail";
        }
        static String name() {
            return "发票明细管理";
        }
    }
    public interface SalesBillDetailCount {
        static String code() {
            return "salesBillDetailCount";
        }
        static String name() {
            return "明细行数量记录";
        }
    }
    public interface TaskLog {
        static String code() {
            return "taskLog";
        }
        static String name() {
            return "定时任务执行日志";
        }
    }
    public interface ExpectionLog {
        static String code() {
            return "expectionLog";
        }
        static String name() {
            return "业务错误日志";
        }
    }
    public interface ProductCodeConfig {
        static String code() {
            return "productCodeConfig";
        }
        static String name() {
            return "主商品配置表";
        }
    }
    public interface ProductNameKeyword {
        static String code() {
            return "productNameKeyword";
        }
        static String name() {
            return "商品名称关键维护";
        }
    }
}
